@@ -31,6 +31,8 @@
 #include <math.h>
 
 #include "interface.h"
+#include "application.h"
+#include "procinfo.h"
 #include "proctable.h"
 #include "procactions.h"
 #include "procdialogs.h"
@@ -468,7 +470,7 @@ on_activate_about (GSimpleAction *,
     NULL
   };
 
-  about_dialog = adw_about_dialog_new_from_appdata ("/org/gnome/gnome-system-monitor/appdata.xml",
+  about_dialog = adw_about_dialog_new_from_appdata ("/org/gnome/gnome-system-monitor/metainfo.xml",
                                                     VERSION);
 
   adw_about_dialog_set_copyright (ADW_ABOUT_DIALOG (about_dialog),
