@@ -1,10 +1,10 @@
-/* -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 #ifndef _GSM_LOAD_GRAPH_H_
 #define _GSM_LOAD_GRAPH_H_
 
 #include <glib.h>
 #include <glibtop/cpu.h>
 
+#include "gsm-graph.h"
 #include "legacy/gsm_color_button.h"
 #include "util.h"
 #include "settings-keys.h"
@@ -13,7 +13,8 @@ enum
 {
   LOAD_GRAPH_CPU,
   LOAD_GRAPH_MEM,
-  LOAD_GRAPH_NET
+  LOAD_GRAPH_NET,
+  LOAD_GRAPH_DISK
 };
 
 enum
@@ -32,25 +33,24 @@ struct LoadGraphLabels
   GtkLabel *net_in_total;
   GtkLabel *net_out;
   GtkLabel *net_out_total;
+  GtkLabel *disk_read;
+  GtkLabel *disk_read_total;
+  GtkLabel *disk_write;
+  GtkLabel *disk_write_total;
 };
 
 struct LoadGraph
   : private procman::NonCopyable
 {
-  static const unsigned GRAPH_MIN_HEIGHT = 40;
-
-  LoadGraph(guint type);
+  LoadGraph (guint type);
   ~LoadGraph();
 
-  unsigned num_bars () const;
+  unsigned get_num_bars (int height) const;
   void     clear_background ();
   bool     is_logarithmic_scale () const;
   char *   get_caption (guint index);
   float    translate_to_log_partial_if_needed (float position_partial);
 
-  double fontsize;
-  double rmargin;
-  /* left margin */
   double indent;
 
   guint n;
@@ -58,13 +58,9 @@ struct LoadGraph
   guint speed;
   guint num_points;
   guint latest;
-  guint draw_width, draw_height;
-  guint render_counter;
-  guint frames_per_unit;
   guint graph_dely;
+  guint num_bars;
   guint real_draw_height;
-  double graph_delx;
-  guint graph_buffer_offset;
 
   std::vector<GdkRGBA> colors;
 
@@ -72,13 +68,7 @@ struct LoadGraph
   std::vector<double*> data;
 
   GtkBox *main_widget;
-  GtkDrawingArea *disp;
-
-  cairo_surface_t *background;
-
-  guint timer_index;
-
-  gboolean draw;
+  GsmGraph *disp;
 
   LoadGraphLabels labels;
   GsmColorButton *mem_color_picker;
@@ -103,6 +93,14 @@ struct LoadGraph
     guint64 max;
     std::vector<unsigned> values;
   } net;
+
+  struct DISK
+  {
+    guint64 last_read, last_write;
+    guint64 time;
+    guint64 max;
+    std::vector<unsigned> values;
+  } disk;
   /* }; */
 };
 
